@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
 import time
 import sys
-import numpy as np
-from collections import Iterable
+from collections.abc import Iterable
 import six
 
+__all__ = ['float_to_str_sig', 'floatformatter', 'issequence']
+
 
 def floatformatter(*args, sig=6, **kwargs):
     return "{" + "0:.{}g".format(sig) + "}"
@@ -38,6 +39,10 @@ def float_to_str_sig(value, *args, sig: int=6, atol: float=1e-7, **kwargs):
                 value = 0.0
         return floatformatter(sig=sig).format(value)
     else:
+        try:
+            import numpy as np
+        except ImportError:
+            raise ImportError("You need numpy for this.")
         value = np.array(value)
         if atol is not None:
             inds = np.where(np.abs(value) < atol)[0]
